OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Складиштето моментално не е достапно",
    "Storage invalid" : "Невалидно складиште",
    "Unknown error" : "Непозната грешка",
    "All files" : "Сите датотеки",
    "Recent" : "Неодамнешни",
    "Favorites" : "Омилени",
    "File could not be found" : "Неможе да се пронајде датотеката",
    "Move or copy" : "Премести или копирај",
    "Download" : "Преземи",
    "Delete" : "Избриши",
    "Home" : "Дома",
    "Close" : "Затвори",
    "Could not create folder \"{dir}\"" : "Неможе да се креира папка \"{dir}\"",
    "This will stop your current uploads." : "Ова ќе го прекине вашето моментално прикачување.",
    "Upload cancelled." : "Преземањето е прекинато.",
    "Processing files …" : "Обработка на датотеки ...",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неможе да се прикачи {filename} бидејќи е директориум или е 0 бајти",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема доволно слободен простор, вие прикачувате {size1} а слободен простор има {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Папката \"{dir}\" не постои повеќе",
    "Not enough free space" : "Нема доволно слободен простор",
    "An unknown error has occurred" : "Се појави непозната грешка",
    "Uploading …" : "Прикачување …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Прикачување на таа датотека не е дозволено",
    "Target folder does not exist any more" : "Папката не постои повеќе",
    "Error when assembling chunks, status code {status}" : "Грешка при составување на парчиња, статусен код {status}",
    "Actions" : "Акции",
    "Rename" : "Преименувај",
    "Copy" : "Копирај",
    "Choose target folder" : "Избери папка",
    "Open" : "Отвори",
    "Delete file" : "Избриши датотека",
    "Delete folder" : "Избриши папка",
    "Disconnect storage" : "Исклучи складиште",
    "Unshare" : "Не споделувај",
    "Could not load info for file \"{file}\"" : "Неможе да се вчитаат информации за датотеката \"{file}\"",
    "Files" : "Датотеки",
    "Details" : "Детали:",
    "Select" : "Избери",
    "Pending" : "Чека",
    "Unable to determine date" : "Неможе да се одреди датумот",
    "This operation is forbidden" : "Операцијата не е дозволена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овој директориум е недостапен, ве молиме проверете ги логовите или контактирајте со администраторот",
    "Could not move \"{file}\", target exists" : "Не може да се премести \"{file}\", веќе постои",
    "Could not move \"{file}\"" : "Не може да се премести \"{file}\"",
    "copy" : "копирај",
    "Could not copy \"{file}\", target exists" : "Не може да се копира \"{file}\", веќе постои",
    "Could not copy \"{file}\"" : "Не може да се копира \"{file}\"",
    "Copied {origin} inside {destination}" : "Копирана {origin} во {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Копирана {origin} и {nbfiles} други датотеки во {destination}",
    "{newName} already exists" : "{newName} веќе постои",
    "Could not rename \"{fileName}\", it does not exist any more" : "Неможе да се преименува \"{fileName}\", датотеката не постои",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" веќе се користи во папката \"{dir}\". Ве молиме изберете друго име.",
    "Could not rename \"{fileName}\"" : "Неможе да се преименува \"{fileName}\"",
    "Could not create file \"{file}\"" : "Неможе да се креира датотека \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Неможе да се креира датотека \"{file}\" бидејќи веќе постои",
    "Could not create folder \"{dir}\" because it already exists" : "Неможе да се креира папка \"{dir}\" бидејќи веќе постои",
    "Error deleting file \"{fileName}\"." : "Грешка при бришење на датотека \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултати од пребарувањето на други места за {tag}{filter}{endtag}",
    "Name" : "Име",
    "Size" : "Големина",
    "Modified" : "Променето",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "_%n file_::_%n files_" : ["%n датотека","%n датотеки"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["вклучувајќи %n скриена","вклучувајќи %n скриени"],
    "You don’t have permission to upload or create files here" : "Немате дозвола да прикачувате или да креирате датотеки",
    "_Uploading %n file_::_Uploading %n files_" : ["Прикачување %n датотека","Прикачување на %n датотеки"],
    "New" : "Ново",
    "Select file range" : "Избери опсег на датотеки",
    "{used} of {quota} used" : "Искористени {used} од {quota}",
    "{used} used" : "Искористени {used}",
    "\"{name}\" is an invalid file name." : "\"{name}\" е невалидно име за датотека.",
    "File name cannot be empty." : "Името на датотеката не може да биде празно.",
    "\"/\" is not allowed inside a file name." : "\"/\" не е дозволено во името.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" не е дозволен вид на датотека",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Складиштето на {owner} е исполнето, повеќе нема да може да сикхронизира и да прикачува датотеки!",
    "Your storage is full, files can not be updated or synced anymore!" : "Вашиот сториџ е полн, датотеките веќе не можат да се освежуваат или синхронизираат!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Скалдиштето на {owner} е скоро исполнето ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Вашиот сториџ е скоро полн ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["содржи '{filter}'","содржи '{filter}'"],
    "View in folder" : "Погледни во папката",
    "Copied!" : "Копирано!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директен линк (работи само за корисници кој имаат директен пристап до датотеката/папката)",
    "Path" : "Патека",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајти"],
    "Favorited" : "Омилени",
    "Favorite" : "Омилен",
    "You can only favorite a single file or folder at a time" : "Можете да додавате само по една датотека или папка во фаворити одеднаш",
    "New folder" : "Нова папка",
    "Upload file" : "Прикачи датотека",
    "Not favorited" : "Нема фаворити",
    "Remove from favorites" : "Отстрани од фаворити",
    "Add to favorites" : "Додади во фаворити",
    "An error occurred while trying to update the tags" : "Се случи грешка додека се обидувавте да ги освежите таговите",
    "Added to favorites" : "Додадени во фаворити",
    "Removed from favorites" : "Отстранети од фаворити",
    "You added {file} to your favorites" : "Додадовте {file} во фаворити",
    "You removed {file} from your favorites" : "Отстранивте {file} од фаворити",
    "File changes" : "Промени на датотеката",
    "Created by {user}" : "Копирано од {user}",
    "Changed by {user}" : "Променето од {user}",
    "Deleted by {user}" : "Избришано од {user}",
    "Restored by {user}" : "Вратено од {user}",
    "Renamed by {user}" : "Преименувано од {user}",
    "Moved by {user}" : "Преместено од {user}",
    "\"remote user\"" : "\"далечен корисник\"",
    "You created {file}" : "Креиравте {file}",
    "You created an encrypted file in {file}" : "Креиравте шифрирана датотека во {file}",
    "{user} created {file}" : "{user} креираше {file}",
    "{user} created an encrypted file in {file}" : "{user} креираше шифрирана датотека во {file}",
    "{file} was created in a public folder" : "{file} е креиран во јавна папка",
    "You changed {file}" : "Изменивте {file}",
    "You changed an encrypted file in {file}" : "Изменивте шифрирана дататека во {file}",
    "{user} changed {file}" : "{user} измени {file}",
    "{user} changed an encrypted file in {file}" : "{user} измени шифрирана дататека во {file}",
    "You deleted {file}" : "Избришавте {file}",
    "You deleted an encrypted file in {file}" : "Избришавте шифрирана датотека во {file}",
    "{user} deleted {file}" : "{user} избриша {file}",
    "{user} deleted an encrypted file in {file}" : "{user} избриша шифрирана датотека во {file}",
    "You restored {file}" : "Вративте {file}",
    "{user} restored {file}" : "{user} врати {file}",
    "You renamed {oldfile} to {newfile}" : "Го преименувавте {oldfile} во {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} го преимени {oldfile} во {newfile}",
    "You moved {oldfile} to {newfile}" : "Го премести {oldfile} во {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} го премести {oldfile} во {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Датотека беше додадена или избришана од  <strong>фаворити</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Датотека или папка е <strong>променета</strong> или <strong>преименувана</strong>",
    "A new file or folder has been <strong>created</strong>" : "Датотека или папка е <strong>креирана</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Датотека или папка е <strong>избришана</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничете известувања за креирање и промени на вашите <strong>омилени датотеки</strong> <em>(само во стримот)</em>",
    "A file or folder has been <strong>restored</strong>" : "Датотека или папка е <strong>вратена</strong>",
    "Unlimited" : "Неограничено",
    "Upload (max. %s)" : "Префрлање (макс. %s)",
    "Accept" : "Прифати",
    "Reject" : "Одбиј",
    "Incoming ownership transfer from {user}" : "Барање за трансфер на сопственост од {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Дали прифаќате {path}?\n\nЗабелешка: Процесот на трансфер одкога ќе прифатите може да трае и повеќе од 1 час.",
    "Ownership transfer failed" : "Неуспешен трансфер на сопственост",
    "Your ownership transfer of {path} to {user} failed." : "Неуспешен трансфер на сопственост на {path} до {user}.",
    "The ownership transfer of {path} from {user} failed." : "Неуспешен трансфер на сопственост на {path} од {user}.",
    "Ownership transfer done" : "Направено е трансфер на сопственост",
    "Your ownership transfer of {path} to {user} has completed." : "Вашиот транфер на сопственост на {path} до {user} е комплетиран.",
    "The ownership transfer of {path} from {user} has completed." : "Трансферот на сопственост на {path} од {user} е комплетиран.",
    "File Management" : "Датотеки",
    "Transfer ownership of a file or folder" : "Трансфер на сопственост на датотека или папка",
    "Choose file or folder to transfer" : "Избери датотека или папка за трансфер",
    "Change" : "Измени",
    "New owner" : "Нов сопственик",
    "Search users" : "Пребарувај корисници",
    "Choose a file or folder to transfer" : "Избери датотека или папка за трансфер",
    "Transfer" : "Трансфер",
    "Transfer {path} to {userid}" : "Трансфер {path} до {userid}",
    "Invalid path selected" : "Избрана невалидна патека",
    "Ownership transfer request sent" : "Испратено барање за трансфер на сопственост",
    "Error while loading the file data" : "Грешка при вчитување на податоците од датотеката",
    "Unable to change the favourite state of the file" : "Неможе да се промени статусот на омимени на датотеката",
    "%s used" : "Искористено %s",
    "%s%% of %s used" : "Искорестено%s%% од %s ",
    "%1$s of %2$s used" : "Искористено %1$s од %2$s",
    "Settings" : "Параметри",
    "Show hidden files" : "Прикажи сокриени датотеки",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Користи ја оваа адреса за <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">пристап преку WebDAV</a>",
    "Toggle grid view" : "Промена во мрежа",
    "No files in here" : "Тука нема датотеки",
    "Upload some content or sync with your devices!" : "Прикачете некоја содржина или синхронизирајте со вашите уреди!",
    "No entries found in this folder" : "Нема ништо во оваа папка",
    "Select all" : "Избери се",
    "Upload too large" : "Фајлот кој се вчитува е преголем",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Датотеките кои се обидувате да ги подигнете ја надминуваат максималната големина за подигнување датотеки на овој сервер.",
    "No favorites yet" : "Сеуште нема фаворити",
    "Files and folders you mark as favorite will show up here" : "Датотеките и папките кои ќе ги означите како чести, ќе се појават тука",
    "Tags" : "Ознаки",
    "Deleted files" : "Избришани датотеки",
    "Shares" : "Споделувања",
    "Shared with others" : "Споделно со други",
    "Shared with you" : "Споделено со тебе",
    "Shared by link" : "Споделено со линк",
    "Deleted shares" : "Избришани споделувања",
    "Text file" : "Текстуална датотека",
    "New text file.txt" : "Нова текстуална датотека file.txt",
    "File handling" : "Ракување со датотеки",
    "Maximum upload size" : "Максимална големина за подигање",
    "max. possible: " : "макс. можно:",
    "Save" : "Зачувај",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Со PHP-FPM може да треба 5 минути за промените да бидат имплементирани.",
    "Missing permissions to edit from here." : "Недостасуваат пермисии за да уредувате од тука",
    "Cancel upload" : "Откажи прикачување",
    "%s of %s used" : "искорестени %s од %s ",
    "%1$s%% of %2$s used" : "искористено %1$s%% од %2$s"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
